@@ -721,7 +721,8 @@ void get_dnd_selection(GtkTreeModel * treemodel, GtkTreePath * path, GtkTreeIter
 	    g_assert_not_reached();
 	sl->en = en;
 	sl->reference = gtk_tree_row_reference_new(treemodel, path);
-	selection_list = g_list_prepend(selection_list, sl);
+	selection_list = g_list_append(selection_list, sl);
+/*	selection_list = g_list_prepend(selection_list, sl);*/
 	/*printf("DBG: added to selection list=%s\n",en->path);*/
     }
     selection_len += (strlen(en->path) + 7);
