@@ -1103,6 +1103,26 @@ void hide_stop(GtkWidget * widget)
 /*XXX put these separate lib */
 
 #define MAX_COMBO_ELEMENTS 13
+static gint translate_key(gint x){
+	switch (x) {
+		case GDK_KP_Divide: return GDK_slash;
+		case GDK_KP_Subtract: return GDK_minus;
+		case GDK_KP_Multiply: return GDK_asterisk;
+		case GDK_KP_Add: return GDK_plus;
+		case GDK_KP_Space: return GDK_space;
+		case GDK_KP_0: return GDK_0;
+		case GDK_KP_1: return GDK_1;
+		case GDK_KP_2: return GDK_2;
+		case GDK_KP_3: return GDK_3;
+		case GDK_KP_4: return GDK_4;
+		case GDK_KP_5: return GDK_5;
+		case GDK_KP_6: return GDK_6;
+		case GDK_KP_7: return GDK_7;
+		case GDK_KP_8: return GDK_8;
+		case GDK_KP_9: return GDK_9;
+	}
+	return x;
+}
 
 static void clean_history_list(GList **list){
 	GList *tmp;
@@ -1313,7 +1333,7 @@ gint on_key_press_history(GtkWidget * entry, GdkEventKey * event, gpointer data)
 	    return TRUE;
 	  }
 	} else {
-	  *c=event->keyval;	
+	  *c=translate_key(event->keyval);	
     	  if (preselection) {
 	        gtk_editable_delete_text (editable,pos1,-1);
       	        text[0]=gtk_editable_get_chars (editable,0,-1);
