@@ -711,7 +711,7 @@ static gboolean treeview_key(GtkWidget *w,
 	    )
 	{
 	    char c;
-	    gchar *f;
+	    gchar *f,*ff;
 	    int emergency=0;
 	    gboolean second_letter_match=FALSE;
 	    gchar *a=NULL,*b=NULL;
@@ -751,7 +751,7 @@ static gboolean treeview_key(GtkWidget *w,
 	    ipath=gtk_tree_model_get_path(treemodel, &iter);
 	    
 	    a=gtk_tree_path_to_string(ipath);
-    	    gtk_tree_model_get(treemodel, &iter, NAME_COLUMN, &f, ENTRY_COLUMN, &en, -1);
+    	    /*gtk_tree_model_get(treemodel, &iter, NAME_COLUMN, &f, ENTRY_COLUMN, &en, -1);*/
 #ifdef DEBUG	
 	    printf("DBG: startpath=%s\n",a);
 #endif	    
@@ -792,8 +792,10 @@ static gboolean treeview_key(GtkWidget *w,
 #ifdef DEBUG	
 	    		printf("DBG: treemodel_get returns null for name column cell!\n");
 #endif			
+			if (f) g_free(f);
 			continue;
 		}
+		ff=f;
 		/*printf("DBG:(%s,%s) %d==%d ... emergency=%d\n",en->path,f,*f,c,emergency);fflush(NULL);*/
 		if (second_letter_match && strlen(f)>1) f++;
 		if (*f == c){
@@ -809,6 +811,7 @@ static gboolean treeview_key(GtkWidget *w,
 			break;
 		} 
 		g_free(b);
+		g_free(ff);
 		b=gtk_tree_path_to_string(ipath);
 #ifdef DEBUG	
 	    printf("DBG: skipping to path=%s\n",b);
@@ -1518,9 +1521,9 @@ GtkTreeView *init_xffm(int argc, char *argv[])
 	    startup = g_strdup(argv[1]);
 	else
 	{
-	    char wd[_POSIX_PATH_MAX];
-	    getcwd(wd, _POSIX_PATH_MAX - 1);
+	    gchar *wd = g_get_current_dir ();
 	    startup = g_strconcat(wd, "/",argv[1],NULL);
+	    g_free(wd);
 	}
     }
     if (!startup) startup=g_strdup(get_xffm_home());
